==> nextcloud-29.0.12.tgz: nextcloud/apps/files_downloadlimit/l10n/sv.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Begränsning för hämtningar",
    "File link share download limit" : "Hämtningsbegränsning för länk-delningar",
    "This app allows limiting the number of downloads for external link shares." : "Denna app tillåter begränsning av antalet nedladdningar för externa länkdelningar.",
    "Limit downloads" : "Begränsa hämtningar",
    "Set download limit" : "Ställ in nedladdningsgräns",
    "Setting a new limit will reset the download count" : "Om du ställer in en ny gräns återställs antalet nedladdningar",
    "The minimum limit is 1" : "Minimigränsen är 1",
    "Failed to set download limit" : "Kunde inte ange nedladdningsgräns",
    "Failed to remove download limit" : "Kunde inte ta bort nedladdningsgränsen",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 tillåten hämtning återstår","{count} tillåtna hämtningar återstår"],
    "Download limit" : "Hämtningsbegränsning",
    "Configure the default download limit for external shares." : "Konfigurera standard nedladdningsgräns för externa delningar.",
    "Set default download limit" : "Ställ in standardgräns för nedladdning",
    "Failed to set default download limit" : "Kunde inte ange standardgräns för nedladdning",
    "You have reached the maximum amount of downloads allowed" : "Du har nått det högsta tillåtna antalet nedladdningar",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Den här delningen har ett begränsat antal nedladdningar. Är du säker på att du vill utföra en ny nedladdning?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.11.tgz: nextcloud/apps/files_downloadlimit/l10n/sv.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Begränsning för hämtningar",
    "File link share download limit" : "Hämtningsbegränsning för länk-delningar",
    "This app allows limiting the number of downloads for external link shares." : "Denna app tillåter begränsning av antalet nedladdningar för externa länkdelningar.",
    "The minimum limit is 1" : "Minimigränsen är 1",
    "Failed to set download limit" : "Kunde inte ange nedladdningsgräns",
    "Failed to remove download limit" : "Kunde inte ta bort nedladdningsgränsen",
    "Limit downloads" : "Begränsa hämtningar",
    "Set download limit" : "Ställ in nedladdningsgräns",
    "Setting a new limit will reset the download count" : "Om du ställer in en ny gräns återställs antalet nedladdningar",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 tillåten hämtning återstår","{count} tillåtna hämtningar återstår"],
    "Download limit" : "Hämtningsbegränsning",
    "Configure the default download limit for external shares." : "Konfigurera standard nedladdningsgräns för externa delningar.",
    "Default download limit for external shares" : "Standardgräns för nedladdning av externa delningar",
    "Set default download limit" : "Ställ in standardgräns för nedladdning",
    "You have reached the maximum amount of downloads allowed" : "Du har nått det högsta tillåtna antalet nedladdningar",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Den här delningen har ett begränsat antal nedladdningar. Är du säker på att du vill utföra en ny nedladdning?",
    "Failed to set default download limit" : "Kunde inte ange standardgräns för nedladdning",
    "Failed to remove default download limit" : "Kunde inte ta bort standardgränsen för nedladdning"
},
"nplurals=2; plural=(n != 1);");
